==> zio-aws-networkmanager_2.13-7.21.15.10-sources.jar: zio/aws/networkmanager/model/CoreNetworkChange.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.networkmanager.model.primitives.ConstrainedString
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CoreNetworkChange(
    `type`: Optional[zio.aws.networkmanager.model.ChangeType] = Optional.Absent,
    action: Optional[zio.aws.networkmanager.model.ChangeAction] =
      Optional.Absent,
    identifier: Optional[ConstrainedString] = Optional.Absent,
    previousValues: Optional[
      zio.aws.networkmanager.model.CoreNetworkChangeValues
    ] = Optional.Absent,
    newValues: Optional[zio.aws.networkmanager.model.CoreNetworkChangeValues] =
      Optional.Absent,
    identifierPath: Optional[ConstrainedString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.CoreNetworkChange = {
    import CoreNetworkChange.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.CoreNetworkChange
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(action.map(value => value.unwrap))(_.action)
      .optionallyWith(
        identifier.map(value =>
          ConstrainedString.unwrap(value): java.lang.String
        )
      )(_.identifier)
      .optionallyWith(previousValues.map(value => value.buildAwsValue()))(
        _.previousValues
      )
      .optionallyWith(newValues.map(value => value.buildAwsValue()))(
        _.newValues
      )
      .optionallyWith(
        identifierPath.map(value =>
          ConstrainedString.unwrap(value): java.lang.String
        )
      )(_.identifierPath)
      .build()
  }
  def asReadOnly: zio.aws.networkmanager.model.CoreNetworkChange.ReadOnly =
    zio.aws.networkmanager.model.CoreNetworkChange.wrap(buildAwsValue())
}
object CoreNetworkChange {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.CoreNetworkChange
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.CoreNetworkChange =
      zio.aws.networkmanager.model.CoreNetworkChange(
        `type`.map(value => value),
        action.map(value => value),
        identifier.map(value => value),
        previousValues.map(value => value.asEditable),
        newValues.map(value => value.asEditable),
        identifierPath.map(value => value)
      )
    def `type`: Optional[zio.aws.networkmanager.model.ChangeType]
    def action: Optional[zio.aws.networkmanager.model.ChangeAction]
    def identifier: Optional[ConstrainedString]
    def previousValues: Optional[
      zio.aws.networkmanager.model.CoreNetworkChangeValues.ReadOnly
    ]
    def newValues: Optional[
      zio.aws.networkmanager.model.CoreNetworkChangeValues.ReadOnly
    ]
    def identifierPath: Optional[ConstrainedString]
    def getType: ZIO[Any, AwsError, zio.aws.networkmanager.model.ChangeType] =
      AwsError.unwrapOptionField("type", `type`)
    def getAction
        : ZIO[Any, AwsError, zio.aws.networkmanager.model.ChangeAction] =
      AwsError.unwrapOptionField("action", action)
    def getIdentifier: ZIO[Any, AwsError, ConstrainedString] =
      AwsError.unwrapOptionField("identifier", identifier)
    def getPreviousValues: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.CoreNetworkChangeValues.ReadOnly
    ] = AwsError.unwrapOptionField("previousValues", previousValues)
    def getNewValues: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.CoreNetworkChangeValues.ReadOnly
    ] = AwsError.unwrapOptionField("newValues", newValues)
    def getIdentifierPath: ZIO[Any, AwsError, ConstrainedString] =
      AwsError.unwrapOptionField("identifierPath", identifierPath)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.CoreNetworkChange
  ) extends zio.aws.networkmanager.model.CoreNetworkChange.ReadOnly {
    override val `type`: Optional[zio.aws.networkmanager.model.ChangeType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value => zio.aws.networkmanager.model.ChangeType.wrap(value))
    override val action: Optional[zio.aws.networkmanager.model.ChangeAction] =
      zio.aws.core.internal
        .optionalFromNullable(impl.action())
        .map(value => zio.aws.networkmanager.model.ChangeAction.wrap(value))
    override val identifier: Optional[ConstrainedString] = zio.aws.core.internal
      .optionalFromNullable(impl.identifier())
      .map(value =>
        zio.aws.networkmanager.model.primitives.ConstrainedString(value)
      )
    override val previousValues: Optional[
      zio.aws.networkmanager.model.CoreNetworkChangeValues.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.previousValues())
      .map(value =>
        zio.aws.networkmanager.model.CoreNetworkChangeValues.wrap(value)
      )
    override val newValues: Optional[
      zio.aws.networkmanager.model.CoreNetworkChangeValues.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.newValues())
      .map(value =>
        zio.aws.networkmanager.model.CoreNetworkChangeValues.wrap(value)
      )
    override val identifierPath: Optional[ConstrainedString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.identifierPath())
        .map(value =>
          zio.aws.networkmanager.model.primitives.ConstrainedString(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.CoreNetworkChange
  ): zio.aws.networkmanager.model.CoreNetworkChange.ReadOnly = new Wrapper(impl)
}

==> zio-aws-networkmanager_3-5.17.157.1-sources.jar: zio/aws/networkmanager/model/CoreNetworkChange.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.networkmanager.model.primitives.ConstrainedString
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CoreNetworkChange(
    `type`: Option[zio.aws.networkmanager.model.ChangeType] = None,
    action: Option[zio.aws.networkmanager.model.ChangeAction] = None,
    identifier: Option[ConstrainedString] = None,
    previousValues: Option[
      zio.aws.networkmanager.model.CoreNetworkChangeValues
    ] = None,
    newValues: Option[zio.aws.networkmanager.model.CoreNetworkChangeValues] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.CoreNetworkChange = {
    import CoreNetworkChange.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.CoreNetworkChange
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(action.map(value => value.unwrap))(_.action)
      .optionallyWith(
        identifier.map(value =>
          ConstrainedString.unwrap(value): java.lang.String
        )
      )(_.identifier)
      .optionallyWith(previousValues.map(value => value.buildAwsValue()))(
        _.previousValues
      )
      .optionallyWith(newValues.map(value => value.buildAwsValue()))(
        _.newValues
      )
      .build()
  }
  def asReadOnly: zio.aws.networkmanager.model.CoreNetworkChange.ReadOnly =
    zio.aws.networkmanager.model.CoreNetworkChange.wrap(buildAwsValue())
}
object CoreNetworkChange {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.CoreNetworkChange
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.CoreNetworkChange =
      zio.aws.networkmanager.model.CoreNetworkChange(
        `type`.map(value => value),
        action.map(value => value),
        identifier.map(value => value),
        previousValues.map(value => value.asEditable),
        newValues.map(value => value.asEditable)
      )
    def `type`: Option[zio.aws.networkmanager.model.ChangeType]
    def action: Option[zio.aws.networkmanager.model.ChangeAction]
    def identifier: Option[ConstrainedString]
    def previousValues
        : Option[zio.aws.networkmanager.model.CoreNetworkChangeValues.ReadOnly]
    def newValues
        : Option[zio.aws.networkmanager.model.CoreNetworkChangeValues.ReadOnly]
    def getType: ZIO[Any, AwsError, zio.aws.networkmanager.model.ChangeType] =
      AwsError.unwrapOptionField("type", `type`)
    def getAction
        : ZIO[Any, AwsError, zio.aws.networkmanager.model.ChangeAction] =
      AwsError.unwrapOptionField("action", action)
    def getIdentifier: ZIO[Any, AwsError, ConstrainedString] =
      AwsError.unwrapOptionField("identifier", identifier)
    def getPreviousValues: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.CoreNetworkChangeValues.ReadOnly
    ] = AwsError.unwrapOptionField("previousValues", previousValues)
    def getNewValues: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.CoreNetworkChangeValues.ReadOnly
    ] = AwsError.unwrapOptionField("newValues", newValues)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.CoreNetworkChange
  ) extends zio.aws.networkmanager.model.CoreNetworkChange.ReadOnly {
    override val `type`: Option[zio.aws.networkmanager.model.ChangeType] = scala
      .Option(impl.`type`())
      .map(value => zio.aws.networkmanager.model.ChangeType.wrap(value))
    override val action: Option[zio.aws.networkmanager.model.ChangeAction] =
      scala
        .Option(impl.action())
        .map(value => zio.aws.networkmanager.model.ChangeAction.wrap(value))
    override val identifier: Option[ConstrainedString] = scala
      .Option(impl.identifier())
      .map(value =>
        zio.aws.networkmanager.model.primitives.ConstrainedString(value)
      )
    override val previousValues: Option[
      zio.aws.networkmanager.model.CoreNetworkChangeValues.ReadOnly
    ] = scala
      .Option(impl.previousValues())
      .map(value =>
        zio.aws.networkmanager.model.CoreNetworkChangeValues.wrap(value)
      )
    override val newValues: Option[
      zio.aws.networkmanager.model.CoreNetworkChangeValues.ReadOnly
    ] = scala
      .Option(impl.newValues())
      .map(value =>
        zio.aws.networkmanager.model.CoreNetworkChangeValues.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.CoreNetworkChange
  ): zio.aws.networkmanager.model.CoreNetworkChange.ReadOnly = new Wrapper(impl)
}
